@@ -10,7 +10,7 @@ use Linux::Inotify2;
 use Carp;
 use Path::Iterator::Rule;
 
-our $VERSION = '1.19';
+our $VERSION = '1.20';
 
 # use Scalar::Util qw(weaken);  # Attempt to address RT#57104, but alas...
 
@@ -101,12 +101,10 @@ sub _parse_events {
 
 # Need to add newly created sub-dirs to the watch list.
 # This is done after filtering. So entire dirs can be ignored efficiently;
-around '_process_events' => sub {
-    my ( $orig, $self, @e ) = @_;
+sub _add_created {
+    my ( $self, @events ) = @_;
 
-    my $events = $self->$orig(@e);
-
-    for my $event (@$events) {
+    for my $event (@events) {
         next unless $event->is_dir && $event->is_created;
 
         $self->_fs_monitor->watch(
@@ -116,9 +114,7 @@ around '_process_events' => sub {
             sub { my $e = shift; $self->_process_events($e); } );
 
     }
-
-    return $events;
-};
+}
 
 1;
 
@@ -132,15 +128,47 @@ AnyEvent::Filesys::Notify::Role::Inotify2 - Use Linux::Inotify2 to watch for cha
 
 =head1 VERSION
 
-version 1.19
+version 1.20
+
+=head1 CONTRIBUTORS
+
+=for stopwords Gasol Wu E<lt>gasol.wu@gmail.comE<gt> who contributed the BSD support for IO::KQueue Dave Hayes E<lt>dave@jetcafe.orgE<gt> Carsten Wolff E<lt>carsten@wolffcarsten.deE<gt>
+
+=over 4
+
+=item *
+
+Gasol Wu E<lt>gasol.wu@gmail.comE<gt> who contributed the BSD support for IO::KQueue
+
+=item *
+
+Dave Hayes E<lt>dave@jetcafe.orgE<gt>
+
+=item *
+
+Carsten Wolff E<lt>carsten@wolffcarsten.deE<gt>
+
+=back
 
 =head1 AUTHOR
 
 Mark Grimes, E<lt>mgrimes@cpan.orgE<gt>
 
+=head1 SOURCE
+
+Source repository is at L<https://github.com/mvgrimes/AnyEvent-Filesys-Notify>.
+
+=head1 BUGS
+
+Please report any bugs or feature requests on the bugtracker website L<http://github.com/mvgrimes/AnyEvent-Filesys-Notify/issues>
+
+When submitting a bug or request, please include a test-file or a
+patch to an existing test-file that illustrates the bug or desired
+feature.
+
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2015 by Mark Grimes, E<lt>mgrimes@cpan.orgE<gt>.
+This software is copyright (c) 2016 by Mark Grimes, E<lt>mgrimes@cpan.orgE<gt>.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
