@@ -9,7 +9,7 @@ use AnyEvent;
 use IO::KQueue;
 use Carp;
 
-our $VERSION = '1.19';
+our $VERSION = '1.20';
 
 # Arbitrary limit on open filehandles before issuing a warning
 our $WARN_FILEHANDLE_LIMIT = 50;
@@ -29,7 +29,8 @@ sub _init {
     # Add each file and each directory
     my @fhs;
     for my $path (@paths) {
-        push @fhs, $self->_watch($path);
+        my $fh = $self->_watch($path);
+        push @fhs, $fh if defined $fh;
     }
 
     # Now use AE to watch the KQueue
@@ -47,22 +48,18 @@ sub _init {
 
 # Need to add newly created items (directories and files).
 # This is done after filtering. So entire dirs can be ignored efficiently.
-around '_process_events' => sub {
-    my ( $orig, $self, @e ) = @_;
+sub _add_created {
+    my ( $self, @events ) = @_;
 
-    my $events = $self->$orig(@e);
-
-    for my $event (@$events) {
+    for my $event (@events) {
         next unless $event->is_created;
 
         my $fh = $self->_watch( $event->path );
-        push @{ $self->_watcher->{fhs} }, $fh;
-
+        push @{ $self->_watcher->{fhs} }, $fh if defined $fh;
     }
 
     $self->_check_filehandle_count;
-    return $events;
-};
+}
 
 sub _watch {
     my ( $self, $path ) = @_;
@@ -72,6 +69,7 @@ sub _watch {
           "KQueue requires a filehandle for each watched file and directory.\n"
           . "You have exceeded the number of filehandles permitted by the OS.\n"
           if $! =~ /^Too many open files/;
+        return if $! =~ /no such file or directory/i;
         croak "Can't open file ($path): $!";
     };
 
@@ -114,20 +112,47 @@ AnyEvent::Filesys::Notify::Role::KQueue - Use IO::KQueue to watch for changed fi
 
 =head1 VERSION
 
-version 1.19
+version 1.20
 
 =head1 CONTRIBUTORS
 
-Thanks to Gasol Wu E<lt>gasol.wu@gmail.comE<gt> who contributed the FreeBSD
-support for IO::KQueue.
+=for stopwords Gasol Wu E<lt>gasol.wu@gmail.comE<gt> who contributed the BSD support for IO::KQueue Dave Hayes E<lt>dave@jetcafe.orgE<gt> Carsten Wolff E<lt>carsten@wolffcarsten.deE<gt>
+
+=over 4
+
+=item *
+
+Gasol Wu E<lt>gasol.wu@gmail.comE<gt> who contributed the BSD support for IO::KQueue
+
+=item *
+
+Dave Hayes E<lt>dave@jetcafe.orgE<gt>
+
+=item *
+
+Carsten Wolff E<lt>carsten@wolffcarsten.deE<gt>
+
+=back
 
 =head1 AUTHOR
 
 Mark Grimes, E<lt>mgrimes@cpan.orgE<gt>
 
+=head1 SOURCE
+
+Source repository is at L<https://github.com/mvgrimes/AnyEvent-Filesys-Notify>.
+
+=head1 BUGS
+
+Please report any bugs or feature requests on the bugtracker website L<http://github.com/mvgrimes/AnyEvent-Filesys-Notify/issues>
+
+When submitting a bug or request, please include a test-file or a
+patch to an existing test-file that illustrates the bug or desired
+feature.
+
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2015 by Mark Grimes, E<lt>mgrimes@cpan.orgE<gt>.
+This software is copyright (c) 2016 by Mark Grimes, E<lt>mgrimes@cpan.orgE<gt>.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
